@@ -1,8 +1,6 @@
 """Unit tests for Device class
     handling device operations
 """
-from operator import itemgetter
-
 from unittest.mock import Mock, patch
 from unittest import TestCase
 from inelsmqtt import InelsMqtt
@@ -17,8 +15,7 @@ from inelsmqtt.const import (
     STATE_CLOSED,
     STATE_OPEN,
     STOP_UP,
-    TEMP_IN,
-    TEMP_OUT,
+    SWITCH,
     DEVICE_TYPE_DICT,
     FRAGMENT_DEVICE_TYPE,
     FRAGMENT_DOMAIN,
@@ -28,7 +25,9 @@ from inelsmqtt.const import (
     SWITCH_ON_SET,
     SWITCH_ON_STATE,
     SWITCH_OFF_STATE,
-    TEMP_SENSOR_DATA,
+    TEMP_IN,
+    TEMP_OUT,
+    TEMPERATURE,
     TOPIC_FRAGMENTS,
     MQTT_HOST,
     MQTT_PORT,
@@ -40,6 +39,7 @@ from inelsmqtt.const import (
     CLIMATE,
     BUTTON,
     RFGB_40,
+    RFSTI_11B,
 )
 
 from tests.const import (
@@ -60,6 +60,10 @@ from tests.const import (
     TEST_SENSOR_TOPIC_STATE,
     TEST_AVAILABILITY_OFF,
     TEST_AVAILABILITY_ON,
+    TEST_SWITCH_WITH_TEMP_STATE_OFF_VALUE,
+    TEST_SWITCH_WITH_TEMP_STATE_ON_VALUE,
+    TEST_SWITCH_WITH_TEMP_TOPIC_CONNECTED,
+    TEST_SWITCH_WITH_TEMP_TOPIC_STATE,
     TEST_TEMPERATURE_DATA,
     TEST_SWITICH_TOPIC_CONNECTED,
     TEST_SWITCH_TOPIC_STATE,
@@ -72,6 +76,8 @@ from tests.const import (
     TEST_BUTTON_RFGB_40_TOPIC_STATE,
     TEST_BUTTON_RFGB_40_TOPIC_CONNECTED,
     TEST_BUTTON_RFGB_40_STATE_VALUE,
+    TEST_SENSOR_RFTC_10_G_TOPIC_STATE,
+    TEST_SENSOR_RFTC_10_G_STATE_VALUE,
 )
 
 
@@ -119,6 +125,14 @@ class DeviceTest(TestCase):
         )
         self.button = Device(InelsMqtt(config), TEST_BUTTON_RFGB_40_TOPIC_STATE, BUTTON)
 
+        self.switch_with_temp = Device(
+            InelsMqtt(config), TEST_SWITCH_WITH_TEMP_TOPIC_STATE, "Switch"
+        )
+
+        self.rftc_10_g = Device(
+            InelsMqtt(config), TEST_SENSOR_RFTC_10_G_TOPIC_STATE, "Sensor"
+        )
+
     def tearDown(self) -> None:
         """Destroy all instances and stop patches"""
         self.switch = None
@@ -127,6 +141,8 @@ class DeviceTest(TestCase):
         self.shutter = None
         self.valve = None
         self.button = None
+        self.switch_with_temp = None
+        self.rftc_10_g = None
 
     def test_initialize_device(self) -> None:
         """Test initialization of device object"""
@@ -227,7 +243,7 @@ class DeviceTest(TestCase):
         self.assertFalse(is_avilable)
 
     @patch(f"{TEST_INELS_MQTT_CLASS_NAMESPACE}.messages")
-    def test_temperature_parsing(self, mock_message) -> None:
+    def test_device_rfti_10b(self, mock_message) -> None:
         """Test parsing teperature data to relevant format."""
         mock_message.return_value = {TEST_SENSOR_TOPIC_STATE: TEST_TEMPERATURE_DATA}
 
@@ -235,33 +251,48 @@ class DeviceTest(TestCase):
         temp_out_decimal_result = 26.7
         batter_decimal_result = 100
 
-        # split by new line and remove last element because is empty
-        data = self.sensor.state.split("\n")[:-1]
+        data = self.sensor.state
 
-        self.assertEqual(len(data), 5)
+        self.assertEqual(temp_in_decimal_result, data.temp_in)
+        self.assertEqual(temp_out_decimal_result, data.temp_out)
+        self.assertEqual(batter_decimal_result, data.battery)
 
-        battery = itemgetter(*TEMP_SENSOR_DATA[BATTERY])(data)
-        temp_in = itemgetter(*TEMP_SENSOR_DATA[TEMP_IN])(data)
-        temp_out = itemgetter(*TEMP_SENSOR_DATA[TEMP_OUT])(data)
+        self.assertIsNotNone(self.sensor.features)
+        self.assertEqual(len(self.sensor.features), 3)
+        self.assertEqual(self.sensor.features, [TEMP_IN, TEMP_OUT, BATTERY])
 
-        self.assertEqual(battery, data[0])
-        self.assertEqual("".join(temp_in), f"{data[2]}{data[1]}")
-        self.assertEqual("".join(temp_out), f"{data[4]}{data[3]}")
+    @patch(f"{TEST_INELS_MQTT_CLASS_NAMESPACE}.messages")
+    def test_device_rftc_10g(self, mock_message) -> None:
+        """Test connectivity and data from device type 12."""
+        mock_message.return_value = {
+            TEST_SENSOR_RFTC_10_G_TOPIC_STATE: TEST_SENSOR_RFTC_10_G_STATE_VALUE
+        }
 
-        temp_in_joined = "".join(temp_in)
-        temp_out_joined = "".join(temp_out)
+        temp = 21.0
+        battery_level = 100
 
-        temp_in_hex = f"0x{temp_in_joined}"
-        temp_out_hex = f"0x{temp_out_joined}"
-        battery_hex = f"0x{battery}"
+        data = self.rftc_10_g.state
 
-        temp_in_dec = int(temp_in_hex, 16) / 100
-        temp_out_dec = int(temp_out_hex, 16) / 100
-        battery_dec = 100 if int(battery_hex, 16) == 0 else 0
+        self.assertEqual(temp, data.temperature)
+        self.assertEqual(battery_level, data.battery)
 
-        self.assertEqual(temp_in_dec, temp_in_decimal_result)
-        self.assertEqual(temp_out_dec, temp_out_decimal_result)
-        self.assertEqual(battery_dec, batter_decimal_result)
+        # change state of the topic
+        mock_message.return_value = {
+            TEST_SENSOR_RFTC_10_G_TOPIC_STATE: b"2C\n00\n81\n00\n00\n"
+        }
+
+        temp = 22.0
+        battery_level = 0
+
+        self.rftc_10_g.get_value()
+        data = self.rftc_10_g.state
+
+        self.assertEqual(temp, data.temperature)
+        self.assertEqual(battery_level, data.battery)
+
+        self.assertIsNotNone(self.rftc_10_g.features)
+        self.assertEqual(len(self.rftc_10_g.features), 2)
+        self.assertEqual(self.rftc_10_g.features, [TEMPERATURE, BATTERY])
 
     @patch(f"{TEST_INELS_MQTT_CLASS_NAMESPACE}.messages")
     def test_device_dimmable_light_test_values(self, mock_message) -> None:
@@ -402,3 +433,30 @@ class DeviceTest(TestCase):
         self.assertEqual(self.button.device_type, BUTTON)
         self.assertEqual(self.button.inels_type, RFGB_40)
         self.assertTrue(self.button.state)
+
+    @patch(f"{TEST_INELS_MQTT_CLASS_NAMESPACE}.messages")
+    def test_device_switch_with_temp(self, mock_message) -> None:
+        """Test switch with temperature."""
+        mock_message.return_value = {
+            TEST_SWITCH_WITH_TEMP_TOPIC_CONNECTED: TEST_AVAILABILITY_ON,
+            TEST_SWITCH_WITH_TEMP_TOPIC_STATE: TEST_SWITCH_WITH_TEMP_STATE_ON_VALUE,
+        }
+
+        self.switch_with_temp.get_value()
+
+        self.assertTrue(self.switch_with_temp.is_available)
+        self.assertEqual(self.switch_with_temp.device_type, SWITCH)
+        self.assertEqual(self.switch_with_temp.inels_type, RFSTI_11B)
+        self.assertTrue(self.switch_with_temp.state.on)
+        self.assertIsNotNone(self.switch_with_temp.state.temperature)
+        self.assertEqual(self.switch_with_temp.state.temperature, 24.5)
+
+        mock_message.return_value = {
+            TEST_SWITCH_WITH_TEMP_TOPIC_CONNECTED: TEST_AVAILABILITY_ON,
+            TEST_SWITCH_WITH_TEMP_TOPIC_STATE: TEST_SWITCH_WITH_TEMP_STATE_OFF_VALUE,
+        }
+
+        self.switch_with_temp.get_value()
+
+        self.assertFalse(self.switch_with_temp.state.on)
+        self.assertEqual(self.switch_with_temp.state.temperature, 21.0)
